import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * An alternate contact attached to an Amazon Web Services account.
 *
 * @schema CfnAlternateContactProps
 */
export interface CfnAlternateContactProps {
    /**
     * The account ID of the AWS account that you want to add an alternate contact to.
     *
     * @schema CfnAlternateContactProps#AccountId
     */
    readonly accountId: string;
    /**
     * The type of alternate contact you want to create.
     *
     * @schema CfnAlternateContactProps#AlternateContactType
     */
    readonly alternateContactType: CfnAlternateContactPropsAlternateContactType;
    /**
     * The email address for the alternate contact.
     *
     * @schema CfnAlternateContactProps#EmailAddress
     */
    readonly emailAddress: string;
    /**
     * The name for the alternate contact.
     *
     * @schema CfnAlternateContactProps#Name
     */
    readonly name: string;
    /**
     * The phone number for the alternate contact.
     *
     * @schema CfnAlternateContactProps#PhoneNumber
     */
    readonly phoneNumber: string;
    /**
     * The title for the alternate contact.
     *
     * @schema CfnAlternateContactProps#Title
     */
    readonly title: string;
}
/**
 * Converts an object of type 'CfnAlternateContactProps' to JSON representation.
 */
export declare function toJson_CfnAlternateContactProps(obj: CfnAlternateContactProps | undefined): Record<string, any> | undefined;
/**
 * The type of alternate contact you want to create.
 *
 * @schema CfnAlternateContactPropsAlternateContactType
 */
export declare enum CfnAlternateContactPropsAlternateContactType {
    /** BILLING */
    BILLING = "BILLING",
    /** OPERATIONS */
    OPERATIONS = "OPERATIONS",
    /** SECURITY */
    SECURITY = "SECURITY"
}
/**
 * A CloudFormation `AwsCommunity::Account::AlternateContact`
 *
 * @cloudformationResource AwsCommunity::Account::AlternateContact
 * @stability external
 * @link https://github.com/aws-cloudformation/community-registry-extensions.git
 */
export declare class CfnAlternateContact extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "AwsCommunity::Account::AlternateContact";
    /**
     * Resource props.
     */
    readonly props: CfnAlternateContactProps;
    /**
     * Create a new `AwsCommunity::Account::AlternateContact`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnAlternateContactProps);
}
